@@ -14,7 +14,7 @@ cipherGUIList is a list of tuples of the form:
 
 cipherGUIList = [
     ("Gie", "Gie's Code", "_Gie's Code", "A simple cipher doable by hand"),
-    ("Ceasar", "Ceasar's Code", "_Ceasar's Code", "Julius Ceasar's code"),
+    ("Caesar", "Caesar's Code", "_Caesar's Code", "Julius Caesar's code"),
     ("Rot", "Rot", "_Rot", "Linear rotation"),
     ("Vigenere", "Vigenere", "_Vigenere", 
         "A version of Rot that uses a private key")
